from zarpy import seed, build_coin, build_die, flip_n, roll_n
from scipy.stats import describe

if __name__ == "__main__":
    seed()

    # p = 11/257 ≈ 0.042801556420233464
    build_coin((11, 257))
    samples = flip_n(100000)
    samples_d = describe(samples)
    print(samples_d)

    # n = 200
    build_die(200)
    samples = roll_n(100000)
    samples_d = describe(samples)
    print(samples_d)



from distutils.core import setup

NAME = "zarpy"

setup(
    name=NAME,
    version="0.9.2",
    author="Alexander Bagnall",
    author_email="abagnalla@gmail.com",
    description="Formally verified biased coin and n-sided die",
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    packages=[NAME],
    package_data={NAME: ['zarpy.so']})



"""
Discrete uniform sampler Ocaml library exposed to Python
"""

import os
from ctypes import PyDLL, RTLD_GLOBAL, c_char_p

curdir = dir_path = os.path.dirname(os.path.realpath(__file__))
dll = PyDLL(f"{curdir}/zarpy.so", RTLD_GLOBAL)
argv_t = c_char_p * 2
argv = argv_t("zarpy.so".encode('utf-8'), None)
dll.caml_startup(argv)

# We export the names explicitly otherwise mypy gets confused and
# generates spurious errors
from zarpy import seed, build_coin, flip, flip_n, build_die, roll, roll_n
